# hstgrism

pip install hstgrism

hstgrism (using python 3) performs reduction of grism images from HST with aXe configuration for HST grisms.

Folder demo shows how to use the software by running the template Notebook.
